==> tool-sql-2.6.0-sources.jar: io/ciera/tool/sql/ooaofooa/domain/StructureMemberSet.java <==
package io.ciera.tool.sql.ooaofooa.domain;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMemberSet;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataTypeSet;
import io.ciera.tool.sql.ooaofooa.value.MemberValueReferenceSet;


public interface StructureMemberSet extends IInstanceSet<StructureMemberSet,StructureMember> {

    // attributes
    public void setName( String m_Name ) throws XtumlException;
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException;
    public void setParent_DT_DT_ID( UniqueId ref_Parent_DT_DT_ID ) throws XtumlException;
    public void setPrevious_Member_ID( UniqueId ref_Previous_Member_ID ) throws XtumlException;
    public void setDimensions( String m_Dimensions ) throws XtumlException;
    public void setMember_ID( UniqueId m_Member_ID ) throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;


    // selections
    public StructuredDataTypeSet R44_has_parent_StructuredDataType() throws XtumlException;
    public DataTypeSet R45_is_defined_by_DataType() throws XtumlException;
    public StructureMemberSet R46_precedes_StructureMember() throws XtumlException;
    public StructureMemberSet R46_succeeds_StructureMember() throws XtumlException;
    public DimensionsSet R53_may_have_Dimensions() throws XtumlException;
    public MemberValueReferenceSet R836_MemberValueReference() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/domain/StructureMemberSet.java <==
package io.ciera.tool.sql.ooaofooa.domain;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.classes.AttributeSet;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMemberSet;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataTypeSet;
import io.ciera.tool.sql.ooaofooa.value.MemberValueReferenceSet;


public interface StructureMemberSet extends IInstanceSet<StructureMemberSet,StructureMember> {

    // attributes
    public void setParent_DT_DT_ID( UniqueId ref_Parent_DT_DT_ID ) throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException;
    public void setMember_ID( UniqueId m_Member_ID ) throws XtumlException;
    public void setPrevious_Member_ID( UniqueId ref_Previous_Member_ID ) throws XtumlException;
    public void setDimensions( String m_Dimensions ) throws XtumlException;


    // selections
    public StructuredDataTypeSet R44_has_parent_StructuredDataType() throws XtumlException;
    public DataTypeSet R45_is_defined_by_DataType() throws XtumlException;
    public StructureMemberSet R46_precedes_StructureMember() throws XtumlException;
    public StructureMemberSet R46_succeeds_StructureMember() throws XtumlException;
    public AttributeSet R4760_Attribute() throws XtumlException;
    public DimensionsSet R53_may_have_Dimensions() throws XtumlException;
    public MemberValueReferenceSet R836_MemberValueReference() throws XtumlException;


}
